import requests
import json


# 名稱: HiAir API client端範例程式
# 撰寫者: HiNet - HiAir , mike huang
# 日期: 2022/06/27

# ===== 設定 API Endpoint =====
# 智慧簡訊
url_sendSMS = 'https://api.sms.hinet.net/api/sendSMS/v1'
# 短簡訊
url_sendShortSMS = 'https://api.sms.hinet.net/api/sendShortSMS/v1'
# 長簡訊
url_sendLongSMS = 'https://api.sms.hinet.net/api/sendLongSMS/v1'
# 查詢簡訊
url_querySMS = 'https://api.sms.hinet.net/api/querySMS/v1'
# 取消預約簡訊
url_cancelSMS = 'https://api.sms.hinet.net/api/cancelSMS/v1'


# ===== 設定 請求欄位 =====
data_base = {
    "username": "請填入帳號",
    "password": "請填入密碼",
}
# --- 發送簡訊 ---
# ex:
# {
# "username": "帳號",
# "password": "密碼",
# "mobile": "門號",
# "message": "簡訊內容",
# "limit_time": 1440,
# "order_time": "220201103000"
# }
data_send_base = dict(data_base)
data_send_base.update({
    "mobile": "請填入收訊手機號碼",
    "message": "請填入簡訊內容",
})
# 簡訊發送 - 一般
data_send_type_01 = dict(data_send_base)
# 簡訊發送 - 設定 limit_time
data_send_type_02 = dict(data_send_base)
data_send_type_02.update({
    "limit_time": 1440,  # 1~1440，單位：分鐘。 (有效範圍外之數值，將預設為 1440 分鐘)
})
# 簡訊發送 - 設定 order_time
data_send_type_03 = dict(data_send_base)
data_send_type_03.update({
    "order_time": "220627091500",  # 格式為 yyMMddHHmmss，yy：不含世紀之西元年，例如 2022 年請輸入 22。
})
# 簡訊發送 - 設定 limit_time, order_time
data_send_type_04 = dict(data_send_base)
data_send_type_04.update({
    "limit_time": 1440,
    "order_time": "220627091500",
})

# --- 查詢簡訊、取消預約簡訊 ---
# ex:
# {
# "username": "帳號",
# "password": "密碼",
# "message_id": " 簡訊 ID",
# "msg_type": 2
# }
# 不指定簡訊類型
data_query_cancel_type_01 = dict(data_base)
data_query_cancel_type_01.update({
    "message_id": "請填入簡訊ID",  # ex: A8784619060309156XXX
})
# 指定簡訊類型
data_query_cancel_type_02 = dict(data_base)
data_query_cancel_type_02.update({
    "message_id": "請填入簡訊ID",  # ex: A8784619060309156XXX
    "msg_type": 2,  # 2:查詢/取消短簡訊 or 12:查詢/取消長簡訊
})


if __name__ == '__main__':
    # ===== 指定 請求欄位 =====
    # --- 發送簡訊 ---
    url = url_sendSMS
    # url = url_sendShortSMS
    # url = url_sendLongSMS
    data = dict(data_send_type_01)
    # data = dict(data_send_type_02)
    # data = dict(data_send_type_03)
    # data = dict(data_send_type_04)

    # --- 查詢簡訊、取消預約簡訊 ---
    # url = url_querySMS
    # url = url_cancelSMS
    # data = dict(data_query_cancel_type_01)
    # data = dict(data_query_cancel_type_02)

    # print("url:", url)
    # print("data:", data)
    # url: https://api.sms.hinet.net/api/sendSMS/v1
    # data: {'username': 'xxx', 'password': 'xxx', 'mobile': '0912345678', 'message': 'hiair web api test', 'limit_time': 1440}

    # ===== 發送請求 =====
    # 參數識別使用json，不用將dict轉為json
    resp = requests.post(url, json=data, timeout=60)
    # 參數識別使用data，須將dict轉為json
    # data = json.dumps(data)
    # resp = requests.post(url, data=data, timeout=60)

    print("resp.status_code:", resp.status_code)
    print("resp.json():", resp.json())
    print("resp.text:", resp.text)

    ret_dict = resp.json()
    if resp.status_code == 200:
        # print("ret_code:", ret_dict['ret_code'])
        # print("ret_content:", ret_dict['ret_content'])
        # ret_code: 0
        # ret_content: A8784619060309156XXX

        # 發送簡訊時:
        if ret_dict['ret_code'] == 0:
            print("message_id:", ret_dict['ret_content'])
            print("msg_type:", ret_dict['msg_type'])
            # message_id: A8784619060309156XXX
            # msg_type: 2
        # 查詢簡訊時:
        if ret_dict['ret_code'] == 0:
            print("ret_content:", ret_dict['ret_content'])
            print("msg_type:", ret_dict['msg_type'])
    if resp.status_code != 200:
        # --- catch error ---
        print("ret_code:", ret_dict['ret_code'])
        print("ret_content:", ret_dict['ret_content'])
        # ret_code: 92
        # ret_content: Json variable type error: limit_time

    # ===== send 回傳範例 =====
    # resp.status_code: 200
    # resp.json(): {'ret_code': 0, 'ret_content': 'A8784619060309156XXX', 'msg_type': 2}

    # resp.status_code: 200
    # resp.json(): {'ret_code': -9, 'ret_content': 'SendLongMessage() exceed max sms number limit(10)', 'msg_type': 12}

    # resp.status_code: 401
    # resp.json(): {'ret_code': 81, 'ret_content': 'Account or password error'}

    # resp.status_code: 400
    # resp.json(): {'ret_code': 90, 'ret_content': 'Json format error'}

    # resp.status_code: 400
    # resp.json(): {'ret_code': 92, 'ret_content': 'Json variable type error: limit_time'}

    # ===== query 回傳範例 =====
    # resp.status_code: 200
    # resp.json(): {'ret_code': 0, 'ret_content': 'Successful:20220628114403', 'msg_type': 2}

    # resp.status_code: 200
    # resp.json(): {'ret_code': 20, 'ret_content': 'reserve message, waiting send', 'msg_type': 2}

    # resp.status_code: 200
    # resp.json(): {'ret_code': 21, 'ret_content': 'reserve Messageage, cancel send', 'msg_type': 2}

    # ===== cancel 回傳範例 =====
    # resp.status_code: 200
    # resp.json(): {'ret_code': 0, 'ret_content': 'Successful', 'msg_type': 2}

    # resp.status_code: 200
    # resp.json(): {'ret_code': 1, 'ret_content': 'Message is not reserving', 'msg_type': 2}

    pass
